<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('booking_order');

// 记录访问日志
record_log('访问预订订单管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加预订
    if ($_POST['action'] == 'add') {
        $booking_no = 'BK' . date('YmdHis') . rand(100, 999); // 生成预订编号
        $guest_name = isset($_POST['guest_name']) ? trim($_POST['guest_name']) : '';
        $guest_mobile = isset($_POST['guest_mobile']) ? trim($_POST['guest_mobile']) : '';
        $guest_email = isset($_POST['guest_email']) ? trim($_POST['guest_email']) : '';
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : null;
        $channel_id = isset($_POST['channel_id']) ? intval($_POST['channel_id']) : 1;
        $arrival_date = isset($_POST['arrival_date']) ? trim($_POST['arrival_date']) : '';
        $departure_date = isset($_POST['departure_date']) ? trim($_POST['departure_date']) : '';
        $adult_count = isset($_POST['adult_count']) ? intval($_POST['adult_count']) : 1;
        $children_count = isset($_POST['children_count']) ? intval($_POST['children_count']) : 0;
        $room_type_id = isset($_POST['room_type_id']) ? intval($_POST['room_type_id']) : 0;
        $room_count = isset($_POST['room_count']) ? intval($_POST['room_count']) : 1;
        $special_requests = isset($_POST['special_requests']) ? trim($_POST['special_requests']) : '';
        $status = 1; // 待确认
        $total_amount = isset($_POST['total_amount']) ? floatval($_POST['total_amount']) : 0;
        $deposit_amount = isset($_POST['deposit_amount']) ? floatval($_POST['deposit_amount']) : 0;
        $breakfast = isset($_POST['breakfast']) ? intval($_POST['breakfast']) : 0;
        $price_per_night = isset($_POST['price_per_night']) ? floatval($_POST['price_per_night']) : 0;

        if (empty($guest_name) || empty($guest_mobile) || empty($arrival_date) || empty($departure_date) || $room_type_id <= 0) {
            $error = '请填写完整预订信息！';
        } else {
            try {
                $pdo->beginTransaction();

                // 插入预订主表
                $stmt = $pdo->prepare("
                    INSERT INTO booking_orders (
                        booking_no, guest_name, guest_mobile, guest_email, member_id, 
                        channel_id, arrival_date, departure_date, room_type_id, room_count, 
                        room_rate, breakfast, total_amount, paid_amount, special_request, status
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                ");

                $result = $stmt->execute([
                    $booking_no,
                    $guest_name,
                    $guest_mobile,
                    $guest_email,
                    $member_id,
                    $channel_id,
                    $arrival_date,
                    $departure_date,
                    $room_type_id,
                    $room_count,
                    $price_per_night,
                    $breakfast,
                    $total_amount,
                    $deposit_amount,
                    $special_requests,
                    $status
                ]);

                if ($result) {
                    $booking_id = $pdo->lastInsertId();

                    // 插入订单房间关联表
                    $stmt = $pdo->prepare("
                        INSERT INTO booking_rooms (
                            booking_id, room_id, status
                        ) VALUES (?, NULL, 1)
                    ");

                    $result2 = $stmt->execute([$booking_id]);

                    if ($result2) {
                        $pdo->commit();
                        record_log("添加新预订：{$guest_name}，预订编号：{$booking_no}");
                        $success = '预订添加成功！';
                    } else {
                        $pdo->rollBack();
                        $error = '添加房间信息失败！';
                    }
                } else {
                    $pdo->rollBack();
                    $error = '预订添加失败！';
                }
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 更新预订状态
    elseif ($_POST['action'] == 'update_status') {
        $booking_id = isset($_POST['booking_id']) ? intval($_POST['booking_id']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 0;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($booking_id <= 0 || $status <= 0) {
            $error = '无效的预订ID或状态！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    UPDATE booking_orders 
                    SET status = ?, special_request = ?, update_time = NOW() 
                    WHERE id = ?
                ");
                $result = $stmt->execute([$status, $remark, $booking_id]);

                if ($result) {
                    $status_text = $status == 1 ? '待确认' : ($status == 2 ? '已确认' : ($status == 3 ? '已取消' : ($status == 4 ? '已入住' : '已离店')));
                    record_log("更新预订状态，ID：{$booking_id}，状态：{$status_text}");
                    $success = '预订状态更新成功！';
                } else {
                    $error = '预订状态更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除预订
    elseif ($_POST['action'] == 'delete') {
        $booking_id = isset($_POST['booking_id']) ? intval($_POST['booking_id']) : 0;

        if ($booking_id <= 0) {
            $error = '无效的预订ID！';
        } else {
            try {
                $pdo->beginTransaction();

                // 先删除关联的房间记录
                $stmt = $pdo->prepare("DELETE FROM booking_rooms WHERE booking_id = ?");
                $result1 = $stmt->execute([$booking_id]);

                // 再删除主订单
                $stmt = $pdo->prepare("DELETE FROM booking_orders WHERE id = ?");
                $result2 = $stmt->execute([$booking_id]);

                if ($result1 && $result2) {
                    $pdo->commit();
                    record_log("删除预订，ID：{$booking_id}");
                    $success = '预订删除成功！';
                } else {
                    $pdo->rollBack();
                    $error = '预订删除失败！';
                }
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 判断是否显示修改状态表单
$edit_booking = null;
if (isset($_GET['edit']) && intval($_GET['edit']) > 0) {
    $booking_id = intval($_GET['edit']);
    try {
        $stmt = $pdo->prepare("
            SELECT b.*, br.room_id, br.status as room_status
            FROM booking_orders b
            LEFT JOIN booking_rooms br ON b.id = br.booking_id
            WHERE b.id = ?
        ");
        $stmt->execute([$booking_id]);
        $edit_booking = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取预订详情失败：' . $e->getMessage();
    }
}

// 判断是否查看详情
$view_booking_id = isset($_GET['view']) ? intval($_GET['view']) : 0;

// 获取会员列表，用于添加预订时选择
try {
    $stmt = $pdo->query("SELECT id, member_no, name, mobile, email FROM guest_members WHERE status = 1 ORDER BY id DESC");
    $members = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员列表失败：' . $e->getMessage();
    $members = [];
}

// 获取房型列表
try {
    $stmt = $pdo->query("SELECT id, type_name, price, description FROM room_types WHERE status = 1 ORDER BY id");
    $room_types = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取房型列表失败：' . $e->getMessage();
    $room_types = [];
}

// 获取渠道列表
try {
    $stmt = $pdo->query("SELECT id, channel_name FROM booking_channels WHERE status = 1 ORDER BY id");
    $channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取渠道列表失败：' . $e->getMessage();
    $channels = [];
}

// 获取预订列表
try {
    $stmt = $pdo->query("
        SELECT b.*, m.name as member_name, c.channel_name, 
               rt.type_name, b.room_count, b.room_rate as price_per_night
        FROM booking_orders b
        LEFT JOIN guest_members m ON b.member_id = m.id
        LEFT JOIN booking_channels c ON b.channel_id = c.id
        LEFT JOIN room_types rt ON b.room_type_id = rt.id
        ORDER BY b.create_time DESC
    ");
    $bookings = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取预订列表失败：' . $e->getMessage();
    $bookings = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单管理</h2>
            <div class="breadcrumb">
                <a href="index.php">预订管理</a> &gt; 订单管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$edit_booking): ?>
                    <a href="order.php?show_form=add" class="btn btn-add">添加预订</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加预订表单 -->
                <h3>添加预订</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="member_id">会员选择（可选）：</label>
                            <select id="member_id" name="member_id">
                                <option value="0">-- 非会员预订 --</option>
                                <?php foreach ($members as $member): ?>
                                    <option value="<?php echo $member['id']; ?>">
                                        <?php echo $member['name']; ?> (<?php echo $member['member_no']; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                            <p class="form-hint">选择会员将自动填充客人信息</p>
                        </div>

                        <div class="form-group">
                            <label for="guest_name">客人姓名：</label>
                            <input type="text" id="guest_name" name="guest_name" required>
                        </div>

                        <div class="form-group">
                            <label for="guest_mobile">手机号码：</label>
                            <input type="text" id="guest_mobile" name="guest_mobile" required>
                        </div>

                        <div class="form-group">
                            <label for="guest_email">电子邮箱：</label>
                            <input type="email" id="guest_email" name="guest_email">
                        </div>

                        <div class="form-group">
                            <label for="channel_id">预订渠道：</label>
                            <select id="channel_id" name="channel_id" required>
                                <?php foreach ($channels as $channel): ?>
                                    <option value="<?php echo $channel['id']; ?>">
                                        <?php echo $channel['channel_name']; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="arrival_date">入住日期：</label>
                            <input type="date" id="arrival_date" name="arrival_date" required>
                        </div>

                        <div class="form-group">
                            <label for="departure_date">离店日期：</label>
                            <input type="date" id="departure_date" name="departure_date" required>
                        </div>

                        <div class="form-group">
                            <label for="adult_count">成人数：</label>
                            <input type="number" id="adult_count" name="adult_count" min="1" value="1" required>
                        </div>

                        <div class="form-group">
                            <label for="children_count">儿童数：</label>
                            <input type="number" id="children_count" name="children_count" min="0" value="0">
                        </div>

                        <div class="form-group">
                            <label for="room_type_id">房型：</label>
                            <select id="room_type_id" name="room_type_id" required>
                                <option value="">-- 请选择房型 --</option>
                                <?php foreach ($room_types as $room_type): ?>
                                    <option value="<?php echo $room_type['id']; ?>">
                                        <?php echo $room_type['type_name']; ?> (¥<?php echo $room_type['price']; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="room_count">房间数：</label>
                            <input type="number" id="room_count" name="room_count" min="1" value="1" required>
                        </div>

                        <div class="form-group">
                            <label for="price_per_night">每晚价格：</label>
                            <input type="number" id="price_per_night" name="price_per_night" min="0" step="0.01" required>
                        </div>

                        <div class="form-group">
                            <label for="total_amount">总金额：</label>
                            <input type="number" id="total_amount" name="total_amount" min="0" step="0.01" required>
                        </div>

                        <div class="form-group">
                            <label for="deposit_amount">订金金额：</label>
                            <input type="number" id="deposit_amount" name="deposit_amount" min="0" step="0.01" value="0">
                        </div>

                        <div class="form-group">
                            <label for="breakfast">含早情况：</label>
                            <select id="breakfast" name="breakfast" required>
                                <option value="0">不含早</option>
                                <option value="1">含单早</option>
                                <option value="2">含双早</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="special_requests">特殊要求：</label>
                            <textarea id="special_requests" name="special_requests" rows="3"></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="order.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($edit_booking): ?>
                <!-- 更新预订状态表单 -->
                <h3>更新预订状态 - <?php echo $edit_booking['booking_no']; ?></h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="update_status">
                        <input type="hidden" name="booking_id" value="<?php echo $edit_booking['id']; ?>">

                        <div class="booking-details">
                            <p><strong>客人姓名：</strong> <?php echo $edit_booking['guest_name']; ?></p>
                            <p><strong>联系方式：</strong> <?php echo $edit_booking['guest_mobile']; ?></p>
                            <p><strong>入住日期：</strong> <?php echo $edit_booking['arrival_date']; ?></p>
                            <p><strong>离店日期：</strong> <?php echo $edit_booking['departure_date']; ?></p>
                        </div>

                        <div class="form-group">
                            <label for="status">预订状态：</label>
                            <select id="status" name="status" required>
                                <option value="1" <?php echo $edit_booking['status'] == 1 ? 'selected' : ''; ?>>待确认</option>
                                <option value="2" <?php echo $edit_booking['status'] == 2 ? 'selected' : ''; ?>>已确认</option>
                                <option value="3" <?php echo $edit_booking['status'] == 3 ? 'selected' : ''; ?>>已取消</option>
                                <option value="4" <?php echo $edit_booking['status'] == 4 ? 'selected' : ''; ?>>已入住</option>
                                <option value="5" <?php echo $edit_booking['status'] == 5 ? 'selected' : ''; ?>>已离店</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="3"><?php echo $edit_booking['special_request']; ?></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="order.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <h3>预订列表</h3>
            <!-- 预订列表 -->
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>预订编号</th>
                            <th>客人姓名</th>
                            <th>预订渠道</th>
                            <th>入住日期</th>
                            <th>离店日期</th>
                            <th>房型</th>
                            <th>总金额</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($bookings as $booking): ?>
                            <tr>
                                <td><?php echo $booking['id']; ?></td>
                                <td><?php echo $booking['booking_no']; ?></td>
                                <td>
                                    <?php echo $booking['guest_name']; ?>
                                    <?php if ($booking['member_id']): ?>
                                        <span class="badge"><?php echo $booking['member_name']; ?></span>
                                    <?php endif; ?>
                                </td>
                                <td><?php echo $booking['channel_name']; ?></td>
                                <td><?php echo $booking['arrival_date']; ?></td>
                                <td><?php echo $booking['departure_date']; ?></td>
                                <td><?php echo $booking['type_name']; ?> (<?php echo $booking['room_count']; ?>间)</td>
                                <td>¥<?php echo number_format($booking['total_amount'], 2); ?></td>
                                <td>
                                    <?php
                                    switch ($booking['status']) {
                                        case 1:
                                            echo '<span class="status-warning">待确认</span>';
                                            break;
                                        case 2:
                                            echo '<span class="status-active">已确认</span>';
                                            break;
                                        case 3:
                                            echo '<span class="status-inactive">已取消</span>';
                                            break;
                                        case 4:
                                            echo '<span class="status-success">已入住</span>';
                                            break;
                                        case 5:
                                            echo '<span class="status-completed">已离店</span>';
                                            break;
                                        default:
                                            echo '<span>未知</span>';
                                    }
                                    ?>
                                </td>
                                <td>
                                    <a href="order.php?view=<?php echo $booking['id']; ?>" class="btn btn-sm btn-details">详情</a>
                                    <a href="order.php?edit=<?php echo $booking['id']; ?>" class="btn btn-sm btn-edit">修改状态</a>

                                    <?php if ($booking['status'] == 1): ?>
                                        <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此预订记录吗？此操作不可恢复！');">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="booking_id" value="<?php echo $booking['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                        </form>
                                    <?php endif; ?>
                                </td>
                            </tr>
                            <?php if ($view_booking_id == $booking['id']): ?>
                                <tr id="booking-<?php echo $booking['id']; ?>">
                                    <td colspan="10" class="details-row">
                                        <div class="booking-details">
                                            <div class="booking-info">
                                                <h4>预订详情</h4>
                                                <p><strong>预订编号：</strong> <?php echo $booking['booking_no']; ?></p>
                                                <p><strong>客人姓名：</strong> <?php echo $booking['guest_name']; ?></p>
                                                <p><strong>联系电话：</strong> <?php echo $booking['guest_mobile']; ?></p>
                                                <p><strong>电子邮箱：</strong> <?php echo $booking['guest_email'] ?: '-'; ?></p>
                                                <p><strong>预订渠道：</strong> <?php echo $booking['channel_name']; ?></p>
                                                <p><strong>入住日期：</strong> <?php echo $booking['arrival_date']; ?></p>
                                                <p><strong>离店日期：</strong> <?php echo $booking['departure_date']; ?></p>
                                                <p><strong>含早情况：</strong>
                                                    <?php
                                                    switch ($booking['breakfast']) {
                                                        case 0:
                                                            echo '不含早';
                                                            break;
                                                        case 1:
                                                            echo '含单早';
                                                            break;
                                                        case 2:
                                                            echo '含双早';
                                                            break;
                                                        default:
                                                            echo '未知';
                                                    }
                                                    ?>
                                                </p>
                                                <p><strong>房型：</strong> <?php echo $booking['type_name']; ?></p>
                                                <p><strong>房间数：</strong> <?php echo $booking['room_count']; ?> 间</p>
                                                <p><strong>每晚价格：</strong> ¥<?php echo number_format($booking['room_rate'], 2); ?></p>
                                                <p><strong>总金额：</strong> ¥<?php echo number_format($booking['total_amount'], 2); ?></p>
                                                <p><strong>已付金额：</strong> ¥<?php echo number_format($booking['paid_amount'], 2); ?></p>
                                                <?php if ($booking['special_request']): ?>
                                                    <p><strong>特殊要求：</strong> <?php echo nl2br($booking['special_request']); ?></p>
                                                <?php endif; ?>
                                                <p><strong>创建时间：</strong> <?php echo date('Y-m-d H:i', strtotime($booking['create_time'])); ?></p>
                                                <?php if ($booking['update_time']): ?>
                                                    <p><strong>最后更新：</strong> <?php echo date('Y-m-d H:i', strtotime($booking['update_time'])); ?></p>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                            <?php endif; ?>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>