<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('checkout');

// 记录访问日志
record_log('访问退房结算页面');

// 初始化变量
$checkin_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
$checkin_order = null;
$total_days = 0;
$room_fee = 0;
$total_fee = 0;
$refund_amount = 0;

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 办理退房
    if ($_POST['action'] == 'checkout') {
        $checkin_id = isset($_POST['checkin_id']) ? intval($_POST['checkin_id']) : 0;
        $damage_amount = isset($_POST['damage_amount']) ? floatval($_POST['damage_amount']) : 0;
        $other_fee = isset($_POST['other_fee']) ? floatval($_POST['other_fee']) : 0;
        $other_fee_remark = isset($_POST['other_fee_remark']) ? trim($_POST['other_fee_remark']) : '';
        $total_amount = isset($_POST['total_amount']) ? floatval($_POST['total_amount']) : 0;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($checkin_id <= 0) {
            $error = '无效的入住记录ID！';
        } else {
            try {
                // 检查入住记录是否存在且未退房
                $stmt = $pdo->prepare("
                    SELECT co.*, r.room_number 
                    FROM checkin_orders co
                    JOIN room_info r ON co.room_id = r.id
                    WHERE co.id = ? AND co.status = 1
                ");
                $stmt->execute([$checkin_id]);
                $checkin = $stmt->fetch();

                if (!$checkin) {
                    $error = '入住记录不存在或已退房！';
                } else {
                    // 开始事务
                    $pdo->beginTransaction();

                    // 更新入住订单状态为已退房
                    $stmt = $pdo->prepare("
                        UPDATE checkin_orders 
                        SET status = 2, checkout_time = NOW(), 
                            total_amount = ?, has_damage = ?, damage_amount = ?,
                            remark = CONCAT(IFNULL(remark, ''), '\n退房备注: ', ?)
                        WHERE id = ?
                    ");
                    $has_damage = $damage_amount > 0 ? 1 : 0;
                    $checkin_updated = $stmt->execute([
                        $total_amount,
                        $has_damage,
                        $damage_amount,
                        $remark,
                        $checkin_id
                    ]);

                    // 更新房间状态为清洁中
                    $stmt = $pdo->prepare("UPDATE room_info SET status = 4 WHERE id = ?");
                    $room_updated = $stmt->execute([$checkin['room_id']]);

                    // 记录房费交易
                    $stmt = $pdo->prepare("
                        INSERT INTO checkin_transactions (
                            checkin_id, type, amount, 
                            payment_method, operator_id, remark
                        ) VALUES (?, 1, ?, 1, ?, '住宿费')
                    ");
                    $room_fee_recorded = $stmt->execute([
                        $checkin_id,
                        $total_amount - $other_fee - $damage_amount,
                        $_SESSION['user_id']
                    ]);

                    // 如果有其他费用，记录交易
                    $other_fee_recorded = true;
                    if ($other_fee > 0) {
                        $stmt = $pdo->prepare("
                            INSERT INTO checkin_transactions (
                                checkin_id, type, amount, 
                                payment_method, operator_id, remark
                            ) VALUES (?, 3, ?, 1, ?, ?)
                        ");
                        $other_fee_recorded = $stmt->execute([
                            $checkin_id,
                            $other_fee,
                            $_SESSION['user_id'],
                            '其他费用: ' . $other_fee_remark
                        ]);
                    }

                    // 如果有损坏赔偿，记录交易
                    $damage_fee_recorded = true;
                    if ($damage_amount > 0) {
                        $stmt = $pdo->prepare("
                            INSERT INTO checkin_transactions (
                                checkin_id, type, amount, 
                                payment_method, operator_id, remark
                            ) VALUES (?, 6, ?, 1, ?, '损坏赔偿费')
                        ");
                        $damage_fee_recorded = $stmt->execute([
                            $checkin_id,
                            $damage_amount,
                            $_SESSION['user_id']
                        ]);
                    }

                    // 计算押金退还金额
                    $refund_amount = $checkin['deposit_amount'] - $damage_amount;

                    // 处理押金退还
                    $deposit_returned = true;
                    if ($refund_amount > 0) {
                        $stmt = $pdo->prepare("
                            INSERT INTO checkin_transactions (
                                checkin_id, type, amount, 
                                payment_method, operator_id, remark
                            ) VALUES (?, 5, ?, 1, ?, '退房退还押金')
                        ");
                        $deposit_returned = $stmt->execute([
                            $checkin_id,
                            $refund_amount,
                            $_SESSION['user_id']
                        ]);
                    }

                    if (
                        $checkin_updated && $room_updated && $room_fee_recorded &&
                        $other_fee_recorded && $damage_fee_recorded && $deposit_returned
                    ) {
                        $pdo->commit();
                        record_log("办理退房：{$checkin['guest_name']}，房间号：{$checkin['room_number']}，消费总额：{$total_amount}");
                        $success = '退房办理成功！';
                    } else {
                        $pdo->rollBack();
                        $error = '退房办理失败！';
                    }
                }
            } catch (PDOException $e) {
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取入住订单详情
if ($checkin_id > 0) {
    try {
        $stmt = $pdo->prepare("
            SELECT co.*, r.room_number, r.room_type_id, t.type_name, t.price,
                  m.member_no, m.name as member_name, u.username AS operator_name
            FROM checkin_orders co
            JOIN room_info r ON co.room_id = r.id
            JOIN room_types t ON r.room_type_id = t.id
            LEFT JOIN guest_members m ON co.member_id = m.id
            LEFT JOIN sys_users u ON co.create_by = u.id
            WHERE co.id = ?
        ");
        $stmt->execute([$checkin_id]);
        $checkin_order = $stmt->fetch();

        if ($checkin_order) {
            // 计算入住天数
            $checkin_time = new DateTime($checkin_order['checkin_time']);
            $now = new DateTime();
            $interval = $checkin_time->diff($now);
            $total_days = $interval->days > 0 ? $interval->days : 1; // 至少算一天

            // 计算房费
            $room_fee = $total_days * $checkin_order['room_rate'];

            // 计算总费用（房费）
            $total_fee = $room_fee;

            // 计算应退还押金（假设没有损坏，全额退还）
            $refund_amount = $checkin_order['deposit_amount'];
        }
    } catch (PDOException $e) {
        $error = '获取入住详情失败：' . $e->getMessage();
    }

    // 获取所有消费记录
    try {
        $stmt = $pdo->prepare("
            SELECT * FROM checkin_transactions
            WHERE checkin_id = ?
            ORDER BY transaction_time DESC
        ");
        $stmt->execute([$checkin_id]);
        $transactions = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取消费记录失败：' . $e->getMessage();
        $transactions = [];
    }
}

// 获取最近的退房记录（用于列表显示）
try {
    $stmt = $pdo->query("
        SELECT co.*, r.room_number, t.type_name,
               m.member_no, u.username AS operator_name
        FROM checkin_orders co
        JOIN room_info r ON co.room_id = r.id
        JOIN room_types t ON r.room_type_id = t.id
        LEFT JOIN guest_members m ON co.member_id = m.id
        LEFT JOIN sys_users u ON co.create_by = u.id
        WHERE co.status = 2
        ORDER BY co.checkout_time DESC
        LIMIT 10
    ");
    $checkout_records = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取退房记录失败：' . $e->getMessage();
    $checkout_records = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
    <script>
        function calculateTotal() {
            const roomFee = parseFloat(document.getElementById('room_fee').value) || 0;
            const damageAmount = parseFloat(document.getElementById('damage_amount').value) || 0;
            const otherFee = parseFloat(document.getElementById('other_fee').value) || 0;
            const totalAmount = roomFee + damageAmount + otherFee;
            document.getElementById('total_amount').value = totalAmount.toFixed(2);

            const depositAmount = parseFloat(document.getElementById('deposit_amount').innerText) || 0;
            const refundAmount = depositAmount - damageAmount;
            document.getElementById('refund_amount').innerText = refundAmount > 0 ? refundAmount.toFixed(2) : '0.00';
        }
    </script>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>退房结算</h2>
            <div class="breadcrumb">
                <a href="index.php">入住与退房管理</a> &gt; 退房结算
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <?php if ($checkin_order): ?>
                <?php if ($checkin_order['status'] == 1): ?>
                    <!-- 办理退房表单 -->
                    <h3>办理退房 - <?php echo $checkin_order['guest_name']; ?> (<?php echo $checkin_order['room_number']; ?>)</h3>
                    <div class="form-container">
                        <form method="post" action="">
                            <input type="hidden" name="action" value="checkout">
                            <input type="hidden" name="checkin_id" value="<?php echo $checkin_order['id']; ?>">

                            <div class="summary-section">
                                <h4>入住信息</h4>
                                <div class="summary-grid">
                                    <div class="summary-item">
                                        <label>入住单号：</label>
                                        <span><?php echo $checkin_order['checkin_no']; ?></span>
                                    </div>
                                    <div class="summary-item">
                                        <label>客人姓名：</label>
                                        <span><?php echo $checkin_order['guest_name']; ?></span>
                                    </div>
                                    <div class="summary-item">
                                        <label>手机号：</label>
                                        <span><?php echo $checkin_order['guest_mobile']; ?></span>
                                    </div>
                                    <div class="summary-item">
                                        <label>房间号：</label>
                                        <span><?php echo $checkin_order['room_number']; ?> (<?php echo $checkin_order['type_name']; ?>)</span>
                                    </div>
                                    <div class="summary-item">
                                        <label>入住时间：</label>
                                        <span><?php echo date('Y-m-d H:i', strtotime($checkin_order['checkin_time'])); ?></span>
                                    </div>
                                    <div class="summary-item">
                                        <label>入住天数：</label>
                                        <span><?php echo $total_days; ?>天</span>
                                    </div>
                                    <div class="summary-item">
                                        <label>房价：</label>
                                        <span>￥<?php echo number_format($checkin_order['room_rate'], 2); ?>/天</span>
                                    </div>
                                    <div class="summary-item">
                                        <label>押金：</label>
                                        <span id="deposit_amount"><?php echo number_format($checkin_order['deposit_amount'], 2); ?></span>
                                    </div>
                                    <?php if ($checkin_order['member_id']): ?>
                                        <div class="summary-item">
                                            <label>会员：</label>
                                            <span><?php echo $checkin_order['member_name']; ?> (<?php echo $checkin_order['member_no']; ?>)</span>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>

                            <h4>费用结算</h4>

                            <div class="form-group">
                                <label for="room_fee">房费总额：</label>
                                <input type="number" id="room_fee" name="room_fee" value="<?php echo $room_fee; ?>" min="0" step="0.01" onchange="calculateTotal()" readonly>
                                <p class="form-hint"><?php echo $checkin_order['room_rate']; ?> × <?php echo $total_days; ?>天</p>
                            </div>

                            <div class="form-group">
                                <label for="damage_amount">损坏赔偿：</label>
                                <input type="number" id="damage_amount" name="damage_amount" value="0" min="0" step="0.01" onchange="calculateTotal()">
                            </div>

                            <div class="form-group">
                                <label for="other_fee">其他费用：</label>
                                <input type="number" id="other_fee" name="other_fee" value="0" min="0" step="0.01" onchange="calculateTotal()">
                            </div>

                            <div class="form-group">
                                <label for="other_fee_remark">其他费用说明：</label>
                                <input type="text" id="other_fee_remark" name="other_fee_remark">
                            </div>

                            <div class="form-group">
                                <label for="total_amount">消费总额：</label>
                                <input type="number" id="total_amount" name="total_amount" value="<?php echo $room_fee; ?>" min="0" step="0.01" readonly>
                            </div>

                            <div class="form-group">
                                <label>应退押金：</label>
                                <span class="form-large" id="refund_amount"><?php echo number_format($refund_amount, 2); ?></span>
                            </div>

                            <div class="form-group">
                                <label for="remark">退房备注：</label>
                                <textarea id="remark" name="remark" rows="3"></textarea>
                            </div>

                            <div class="form-buttons">
                                <button type="submit" class="btn btn-primary" onclick="return confirm('确定要办理退房吗？此操作不可撤销。')">办理退房</button>
                                <a href="index.php" class="btn btn-secondary">取消</a>
                            </div>
                        </form>
                    </div>
                <?php else: ?>
                    <!-- 已退房订单详情 -->
                    <h3>退房详情 - <?php echo $checkin_order['guest_name']; ?> (<?php echo $checkin_order['room_number']; ?>)</h3>
                    <div class="summary-section">
                        <h4>基本信息</h4>
                        <div class="summary-grid">
                            <div class="summary-item">
                                <label>入住单号：</label>
                                <span><?php echo $checkin_order['checkin_no']; ?></span>
                            </div>
                            <div class="summary-item">
                                <label>客人姓名：</label>
                                <span><?php echo $checkin_order['guest_name']; ?></span>
                            </div>
                            <div class="summary-item">
                                <label>手机号：</label>
                                <span><?php echo $checkin_order['guest_mobile']; ?></span>
                            </div>
                            <div class="summary-item">
                                <label>房间号：</label>
                                <span><?php echo $checkin_order['room_number']; ?> (<?php echo $checkin_order['type_name']; ?>)</span>
                            </div>
                            <div class="summary-item">
                                <label>入住时间：</label>
                                <span><?php echo date('Y-m-d H:i', strtotime($checkin_order['checkin_time'])); ?></span>
                            </div>
                            <div class="summary-item">
                                <label>退房时间：</label>
                                <span><?php echo date('Y-m-d H:i', strtotime($checkin_order['checkout_time'])); ?></span>
                            </div>
                            <div class="summary-item">
                                <label>房价：</label>
                                <span>￥<?php echo number_format($checkin_order['room_rate'], 2); ?>/天</span>
                            </div>
                            <div class="summary-item">
                                <label>消费总额：</label>
                                <span>￥<?php echo number_format($checkin_order['total_amount'], 2); ?></span>
                            </div>
                            <div class="summary-item">
                                <label>押金：</label>
                                <span>￥<?php echo number_format($checkin_order['deposit_amount'], 2); ?></span>
                            </div>
                            <?php if ($checkin_order['has_damage']): ?>
                                <div class="summary-item">
                                    <label>损坏赔偿：</label>
                                    <span>￥<?php echo number_format($checkin_order['damage_amount'], 2); ?></span>
                                </div>
                            <?php endif; ?>
                            <div class="summary-item">
                                <label>操作员：</label>
                                <span><?php echo $checkin_order['operator_name']; ?></span>
                            </div>
                            <?php if ($checkin_order['remark']): ?>
                                <div class="summary-item wide">
                                    <label>备注：</label>
                                    <span><?php echo nl2br($checkin_order['remark']); ?></span>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>

                    <?php if ($transactions): ?>
                        <h4>交易记录</h4>
                        <div class="data-list">
                            <table class="data-table">
                                <thead>
                                    <tr>
                                        <th>ID</th>
                                        <th>交易类型</th>
                                        <th>金额</th>
                                        <th>支付方式</th>
                                        <th>交易时间</th>
                                        <th>备注</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($transactions as $transaction): ?>
                                        <tr>
                                            <td><?php echo $transaction['id']; ?></td>
                                            <td>
                                                <?php
                                                $type_texts = [
                                                    1 => '房费',
                                                    2 => '餐饮',
                                                    3 => '其他消费',
                                                    4 => '押金收取',
                                                    5 => '押金退还',
                                                    6 => '押金扣除'
                                                ];
                                                echo isset($type_texts[$transaction['type']]) ? $type_texts[$transaction['type']] : '未知';
                                                ?>
                                            </td>
                                            <td>￥<?php echo number_format($transaction['amount'], 2); ?></td>
                                            <td>
                                                <?php
                                                $payment_methods = [
                                                    1 => '现金',
                                                    2 => '信用卡',
                                                    3 => '微信',
                                                    4 => '支付宝'
                                                ];
                                                echo isset($payment_methods[$transaction['payment_method']]) ? $payment_methods[$transaction['payment_method']] : '未知';
                                                ?>
                                            </td>
                                            <td><?php echo date('Y-m-d H:i', strtotime($transaction['transaction_time'])); ?></td>
                                            <td><?php echo $transaction['remark']; ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>

                    <div class="form-buttons">
                        <a href="invoice.php?checkin_id=<?php echo $checkin_order['id']; ?>" class="btn btn-primary">打印发票</a>
                        <a href="index.php" class="btn btn-secondary">返回</a>
                    </div>
                <?php endif; ?>
            <?php else: ?>
                <!-- 退房记录列表 -->
                <h3>最近退房记录</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>入住单号</th>
                                <th>客人姓名</th>
                                <th>房间号</th>
                                <th>入住时间</th>
                                <th>退房时间</th>
                                <th>消费总额</th>
                                <th>操作员</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($checkout_records as $record): ?>
                                <tr>
                                    <td><?php echo $record['checkin_no']; ?></td>
                                    <td><?php echo $record['guest_name']; ?></td>
                                    <td><?php echo $record['room_number']; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($record['checkin_time'])); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($record['checkout_time'])); ?></td>
                                    <td>￥<?php echo number_format($record['total_amount'], 2); ?></td>
                                    <td><?php echo $record['operator_name']; ?></td>
                                    <td>
                                        <a href="checkout.php?id=<?php echo $record['id']; ?>" class="btn btn-sm btn-details">查看详情</a>
                                        <a href="invoice.php?checkin_id=<?php echo $record['id']; ?>" class="btn btn-sm btn-primary">打印发票</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>

                            <?php if (empty($checkout_records)): ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无退房记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <div class="info-box">
                    <p>请从首页或入住登记页面选择需要办理退房的客人。</p>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>