<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('checkin');

// 记录访问日志
record_log('访问发票管理页面');

// 初始化变量
$checkin_id = isset($_GET['checkin_id']) ? intval($_GET['checkin_id']) : 0;
$invoice_id = isset($_GET['invoice_id']) ? intval($_GET['invoice_id']) : 0;
$print_view = isset($_GET['print']) && $_GET['print'] == 'true';
$checkin_order = null;
$invoice = null;

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 申请发票
    if ($_POST['action'] == 'apply_invoice') {
        $checkin_id = isset($_POST['checkin_id']) ? intval($_POST['checkin_id']) : 0;
        $title = isset($_POST['invoice_title']) ? trim($_POST['invoice_title']) : '';
        $tax_number = isset($_POST['tax_number']) ? trim($_POST['tax_number']) : '';
        $invoice_type = isset($_POST['invoice_type']) ? intval($_POST['invoice_type']) : 1;
        $content = isset($_POST['invoice_content']) ? intval($_POST['invoice_content']) : 1;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $email = isset($_POST['email']) ? trim($_POST['email']) : '';
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($checkin_id <= 0 || empty($title) || $amount <= 0) {
            $error = '请填写完整的发票信息！';
        } else {
            try {
                // 检查入住记录是否存在
                $stmt = $pdo->prepare("
                    SELECT co.*, r.room_number, u.username as operator_name
                    FROM checkin_orders co
                    JOIN room_info r ON co.room_id = r.id
                    LEFT JOIN sys_users u ON co.create_by = u.id
                    WHERE co.id = ?
                ");
                $stmt->execute([$checkin_id]);
                $checkin = $stmt->fetch();

                if (!$checkin) {
                    $error = '入住记录不存在！';
                } else {
                    // 生成发票号
                    $invoice_no = 'INV' . date('YmdHis') . rand(1000, 9999);

                    // 添加发票记录
                    $stmt = $pdo->prepare("
                        INSERT INTO checkin_invoices (
                            checkin_id, invoice_no, title, tax_number, 
                            invoice_type, content, amount, email, 
                            status, operator_id, remark
                        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, 1, ?, ?)
                    ");
                    $result = $stmt->execute([
                        $checkin_id,
                        $invoice_no,
                        $title,
                        $tax_number,
                        $invoice_type,
                        $content,
                        $amount,
                        $email,
                        $_SESSION['user_id'],
                        $remark
                    ]);

                    if ($result) {
                        $new_invoice_id = $pdo->lastInsertId();
                        record_log("申请发票：客人 {$checkin['guest_name']}，房间 {$checkin['room_number']}，金额：{$amount}，抬头：{$title}");
                        $success = '发票申请成功！';

                        // 跳转到打印页面
                        header("Location: invoice.php?invoice_id={$new_invoice_id}&print=true");
                        exit;
                    } else {
                        $error = '发票申请失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 标记发票状态
    elseif ($_POST['action'] == 'mark_status') {
        $invoice_id = isset($_POST['invoice_id']) ? intval($_POST['invoice_id']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 0;
        $status_remark = isset($_POST['status_remark']) ? trim($_POST['status_remark']) : '';

        if ($invoice_id <= 0) {
            $error = '无效的发票ID！';
        } else {
            try {
                // 获取发票信息，用于日志记录
                $stmt = $pdo->prepare("
                    SELECT i.*, co.guest_name, r.room_number 
                    FROM checkin_invoices i
                    JOIN checkin_orders co ON i.checkin_id = co.id
                    JOIN room_info r ON co.room_id = r.id
                    WHERE i.id = ?
                ");
                $stmt->execute([$invoice_id]);
                $invoice = $stmt->fetch();

                if (!$invoice) {
                    $error = '发票记录不存在！';
                } else {
                    // 更新发票状态
                    $stmt = $pdo->prepare("
                        UPDATE checkin_invoices 
                        SET status = ?
                        WHERE id = ?
                    ");
                    $result = $stmt->execute([
                        $status,
                        $invoice_id
                    ]);

                    if ($result) {
                        $status_texts = [
                            1 => '已申请',
                            2 => '已开具',
                            3 => '已发送',
                            4 => '已取消'
                        ];
                        $status_text = isset($status_texts[$status]) ? $status_texts[$status] : '未知';
                        record_log("更新发票状态：发票号 {$invoice['invoice_no']}，状态：{$status_text}，客人：{$invoice['guest_name']}");
                        $success = '发票状态更新成功！';
                    } else {
                        $error = '发票状态更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取单个发票详情
if ($invoice_id > 0) {
    try {
        $stmt = $pdo->prepare("
            SELECT i.*, co.checkin_no, co.guest_name, co.guest_mobile, 
                co.checkin_time, co.checkout_time, co.total_amount,
                r.room_number, t.type_name, co.room_rate,
                u.username AS operator_name
            FROM checkin_invoices i
            JOIN checkin_orders co ON i.checkin_id = co.id
            JOIN room_info r ON co.room_id = r.id
            JOIN room_types t ON r.room_type_id = t.id
            LEFT JOIN sys_users u ON i.operator_id = u.id
            WHERE i.id = ?
        ");
        $stmt->execute([$invoice_id]);
        $invoice = $stmt->fetch();

        if ($invoice) {
            $checkin_id = $invoice['checkin_id'];
        }
    } catch (PDOException $e) {
        $error = '获取发票详情失败：' . $e->getMessage();
    }
}

// 获取入住订单详情
if ($checkin_id > 0 && !$invoice) {
    try {
        $stmt = $pdo->prepare("
            SELECT co.*, r.room_number, t.type_name, t.price,
                  m.member_no, m.name as member_name, u.username AS operator_name
            FROM checkin_orders co
            JOIN room_info r ON co.room_id = r.id
            JOIN room_types t ON r.room_type_id = t.id
            LEFT JOIN guest_members m ON co.member_id = m.id
            LEFT JOIN sys_users u ON co.create_by = u.id
            WHERE co.id = ?
        ");
        $stmt->execute([$checkin_id]);
        $checkin_order = $stmt->fetch();

        // 获取该订单的所有发票
        if ($checkin_order) {
            $stmt = $pdo->prepare("
                SELECT * FROM checkin_invoices
                WHERE checkin_id = ?
                ORDER BY issue_time DESC
            ");
            $stmt->execute([$checkin_id]);
            $order_invoices = $stmt->fetchAll();
        }
    } catch (PDOException $e) {
        $error = '获取入住详情失败：' . $e->getMessage();
    }
}

// 获取最近的发票记录（用于列表显示）
if (!$checkin_id && !$invoice_id) {
    try {
        $stmt = $pdo->query("
            SELECT i.*, co.guest_name, r.room_number, u.username AS operator_name
            FROM checkin_invoices i
            JOIN checkin_orders co ON i.checkin_id = co.id
            JOIN room_info r ON co.room_id = r.id
            LEFT JOIN sys_users u ON i.operator_id = u.id
            ORDER BY i.issue_time DESC
            LIMIT 20
        ");
        $recent_invoices = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取发票记录失败：' . $e->getMessage();
        $recent_invoices = [];
    }

    // 获取活跃的入住订单（用于下拉选择）
    try {
        $stmt = $pdo->query("
            SELECT co.id, co.checkin_no, co.guest_name, r.room_number, co.total_amount
            FROM checkin_orders co
            JOIN room_info r ON co.room_id = r.id
            WHERE co.status = 2
            ORDER BY co.checkout_time DESC
            LIMIT 50
        ");
        $checkout_orders = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取退房订单列表失败：' . $e->getMessage();
        $checkout_orders = [];
    }
}

// 如果是打印视图，只显示发票内容
if ($print_view && $invoice) {
    // 计算入住天数
    $checkin_time = new DateTime($invoice['checkin_time']);
    $checkout_time = new DateTime($invoice['checkout_time'] ?: 'now');
    $interval = $checkin_time->diff($checkout_time);
    $total_days = $interval->days > 0 ? $interval->days : 1; // 至少算一天
?>
    <!DOCTYPE html>
    <html lang="zh-CN">

    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>电子发票 - <?php echo $invoice['invoice_no']; ?></title>
        <style>
            body {
                font-family: Arial, sans-serif;
                margin: 0;
                padding: 20px;
                color: #333;
            }

            .invoice-container {
                max-width: 800px;
                margin: 0 auto;
                border: 1px solid #ddd;
                padding: 20px;
            }

            .invoice-header {
                text-align: center;
                margin-bottom: 20px;
                border-bottom: 2px solid #005eb8;
                padding-bottom: 10px;
            }

            .invoice-title {
                font-size: 24px;
                color: #005eb8;
                margin-bottom: 10px;
            }

            .invoice-number {
                font-size: 14px;
                color: #666;
            }

            .invoice-info {
                display: flex;
                justify-content: space-between;
                margin-bottom: 20px;
            }

            .invoice-info-col {
                flex: 1;
            }

            .invoice-table {
                width: 100%;
                border-collapse: collapse;
                margin-bottom: 20px;
            }

            .invoice-table th,
            .invoice-table td {
                border: 1px solid #ddd;
                padding: 8px;
                text-align: left;
            }

            .invoice-table th {
                background-color: #f5f5f5;
            }

            .invoice-footer {
                display: flex;
                justify-content: space-between;
                border-top: 1px solid #ddd;
                padding-top: 10px;
                margin-top: 20px;
                font-size: 14px;
            }

            .invoice-stamp {
                text-align: center;
                margin-top: 40px;
            }

            .buttons {
                text-align: center;
                margin-top: 20px;
            }

            .print-btn {
                background-color: #005eb8;
                color: white;
                border: none;
                padding: 10px 20px;
                cursor: pointer;
                font-size: 16px;
            }

            .back-btn {
                background-color: #666;
                color: white;
                border: none;
                padding: 10px 20px;
                cursor: pointer;
                font-size: 16px;
                margin-left: 10px;
            }

            @media print {
                .buttons {
                    display: none;
                }

                body {
                    padding: 0;
                }
            }
        </style>
    </head>

    <body>
        <div class="invoice-container">
            <div class="invoice-header">
                <div class="invoice-title">酒店住宿电子发票</div>
                <div class="invoice-number">发票号码：<?php echo $invoice['invoice_no']; ?></div>
            </div>

            <div class="invoice-info">
                <div class="invoice-info-col">
                    <p><strong>发票类型：</strong>
                        <?php echo $invoice['invoice_type'] == 1 ? '增值税普通发票' : '增值税专用发票'; ?>
                    </p>
                    <p><strong>发票内容：</strong>
                        <?php
                        $content_types = [
                            1 => '住宿费',
                            2 => '餐饮费',
                            3 => '综合服务费'
                        ];
                        echo isset($content_types[$invoice['content']]) ? $content_types[$invoice['content']] : '未知';
                        ?>
                    </p>
                    <p><strong>开票日期：</strong> <?php echo date('Y-m-d', strtotime($invoice['issue_time'])); ?></p>
                </div>
                <div class="invoice-info-col">
                    <p><strong>购买方名称：</strong> <?php echo $invoice['title']; ?></p>
                    <p><strong>纳税人识别号：</strong> <?php echo $invoice['tax_number'] ?: '-'; ?></p>
                    <p><strong>联系方式：</strong> <?php echo $invoice['email'] ?: '-'; ?></p>
                </div>
            </div>

            <table class="invoice-table">
                <thead>
                    <tr>
                        <th>项目</th>
                        <th>房型</th>
                        <th>入住日期</th>
                        <th>离店日期</th>
                        <th>天数</th>
                        <th>单价(元)</th>
                        <th>金额(元)</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td>
                            <?php
                            echo isset($content_types[$invoice['content']]) ? $content_types[$invoice['content']] : '住宿费';
                            ?>
                        </td>
                        <td><?php echo $invoice['room_number']; ?> (<?php echo $invoice['type_name']; ?>)</td>
                        <td><?php echo date('Y-m-d', strtotime($invoice['checkin_time'])); ?></td>
                        <td><?php echo $invoice['checkout_time'] ? date('Y-m-d', strtotime($invoice['checkout_time'])) : '-'; ?></td>
                        <td><?php echo $total_days; ?></td>
                        <td><?php echo number_format($invoice['room_rate'], 2); ?></td>
                        <td><?php echo number_format($invoice['amount'], 2); ?></td>
                    </tr>
                    <tr>
                        <td colspan="6" style="text-align: right;"><strong>合计：</strong></td>
                        <td><strong>￥<?php echo number_format($invoice['amount'], 2); ?></strong></td>
                    </tr>
                </tbody>
            </table>

            <div>
                <p><strong>金额大写：</strong>
                    <?php
                    $digitUppercase = '';
                    $num = $invoice['amount'];
                    $digit = ['零', '壹', '贰', '叁', '肆', '伍', '陆', '柒', '捌', '玖'];
                    $unit = ['', '拾', '佰', '仟', '万', '拾', '佰', '仟', '亿', '拾', '佰', '仟'];
                    $pointer = ['角', '分'];

                    // 简化的大写金额转换
                    $num = sprintf("%.2f", $num);
                    $item = explode(".", $num);
                    $int = $item[0];
                    $dec = isset($item[1]) ? $item[1] : '';

                    // 整数部分
                    if ($int) {
                        $int_len = strlen($int);
                        for ($i = 0; $i < $int_len; $i++) {
                            $digitUppercase .= $digit[$int[$i]] . $unit[$int_len - $i - 1];
                        }
                        $digitUppercase .= '元';
                    }

                    // 小数部分
                    if ($dec) {
                        for ($i = 0; $i < 2; $i++) {
                            if (isset($dec[$i]) && $dec[$i] > 0) {
                                $digitUppercase .= $digit[$dec[$i]] . $pointer[$i];
                            }
                        }
                    } else {
                        $digitUppercase .= '整';
                    }

                    echo $digitUppercase;
                    ?>
                </p>
            </div>

            <div class="invoice-footer">
                <div>
                    <p><strong>客户：</strong> <?php echo $invoice['guest_name']; ?></p>
                    <p><strong>联系电话：</strong> <?php echo $invoice['guest_mobile']; ?></p>
                </div>
                <div>
                    <p><strong>操作员：</strong> <?php echo $invoice['operator_name']; ?></p>
                    <?php if ($invoice['remark']): ?>
                        <p><strong>备注：</strong> <?php echo nl2br($invoice['remark']); ?></p>
                    <?php endif; ?>
                </div>
            </div>

            <div class="invoice-stamp">
                <p>酒店电子印章</p>
                <p><?php echo date('Y-m-d'); ?></p>
            </div>
        </div>

        <div class="buttons">
            <button class="print-btn" onclick="window.print()">打印发票</button>
            <a href="invoice.php?invoice_id=<?php echo $invoice['id']; ?>">
                <button class="back-btn">返回详情</button>
            </a>
        </div>
    </body>

    </html>
<?php
    exit;
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>发票管理</h2>
            <div class="breadcrumb">
                <a href="index.php">入住与退房管理</a> &gt; 发票管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <?php if ($invoice): ?>
                <!-- 显示发票详情 -->
                <h3>发票详情 - <?php echo $invoice['invoice_no']; ?></h3>
                <div class="summary-section">
                    <div class="summary-grid">
                        <div class="summary-item">
                            <label>发票号码：</label>
                            <span><?php echo $invoice['invoice_no']; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>发票抬头：</label>
                            <span><?php echo $invoice['title']; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>纳税人识别号：</label>
                            <span><?php echo $invoice['tax_number'] ?: '-'; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>发票类型：</label>
                            <span><?php echo $invoice['invoice_type'] == 1 ? '增值税普通发票' : '增值税专用发票'; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>开票内容：</label>
                            <span>
                                <?php
                                $content_types = [
                                    1 => '住宿费',
                                    2 => '餐饮费',
                                    3 => '综合服务费'
                                ];
                                echo isset($content_types[$invoice['content']]) ? $content_types[$invoice['content']] : '未知';
                                ?>
                            </span>
                        </div>
                        <div class="summary-item">
                            <label>开票金额：</label>
                            <span>￥<?php echo number_format($invoice['amount'], 2); ?></span>
                        </div>
                        <div class="summary-item">
                            <label>开票状态：</label>
                            <span>
                                <?php
                                $status_classes = [
                                    1 => 'status-active',
                                    2 => 'status-success',
                                    3 => 'status-success',
                                    4 => 'status-inactive'
                                ];
                                $status_texts = [
                                    1 => '已申请',
                                    2 => '已开具',
                                    3 => '已发送',
                                    4 => '已取消'
                                ];
                                $status_class = isset($status_classes[$invoice['status']]) ? $status_classes[$invoice['status']] : '';
                                $status_text = isset($status_texts[$invoice['status']]) ? $status_texts[$invoice['status']] : '未知';
                                echo "<span class=\"{$status_class}\">{$status_text}</span>";
                                ?>
                            </span>
                        </div>
                        <div class="summary-item">
                            <label>申请时间：</label>
                            <span><?php echo date('Y-m-d H:i', strtotime($invoice['issue_time'])); ?></span>
                        </div>
                        <div class="summary-item">
                            <label>客人姓名：</label>
                            <span><?php echo $invoice['guest_name']; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>房间号：</label>
                            <span><?php echo $invoice['room_number']; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>入住时间：</label>
                            <span><?php echo date('Y-m-d H:i', strtotime($invoice['checkin_time'])); ?></span>
                        </div>
                        <div class="summary-item">
                            <label>退房时间：</label>
                            <span><?php echo $invoice['checkout_time'] ? date('Y-m-d H:i', strtotime($invoice['checkout_time'])) : '-'; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>电子邮箱：</label>
                            <span><?php echo $invoice['email'] ?: '-'; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>操作人：</label>
                            <span><?php echo $invoice['operator_name']; ?></span>
                        </div>
                        <?php if ($invoice['remark']): ?>
                            <div class="summary-item wide">
                                <label>备注：</label>
                                <span><?php echo nl2br($invoice['remark']); ?></span>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <div class="action-buttons">
                    <a href="invoice.php?invoice_id=<?php echo $invoice['id']; ?>&print=true" class="btn btn-primary">打印发票</a>

                    <?php if ($invoice['status'] == 1): ?>
                        <button class="btn btn-success" onclick="document.getElementById('mark-issued-form').style.display='block';">标记为已开具</button>
                        <button class="btn btn-danger" onclick="document.getElementById('mark-cancelled-form').style.display='block';">取消发票</button>
                    <?php endif; ?>

                    <?php if ($invoice['status'] == 2): ?>
                        <button class="btn btn-warning" onclick="document.getElementById('mark-sent-form').style.display='block';">标记为已发送</button>
                    <?php endif; ?>

                    <a href="invoice.php" class="btn btn-secondary">返回列表</a>
                </div>

                <!-- 标记为已开具表单 -->
                <?php if ($invoice['status'] == 1): ?>
                    <div id="mark-issued-form" class="form-popup" style="display: none;">
                        <div class="form-container">
                            <h4>标记为已开具</h4>
                            <form method="post" action="">
                                <input type="hidden" name="action" value="mark_status">
                                <input type="hidden" name="invoice_id" value="<?php echo $invoice['id']; ?>">
                                <input type="hidden" name="status" value="2">

                                <div class="form-group">
                                    <label for="status_remark">备注：</label>
                                    <textarea id="status_remark" name="status_remark" rows="3"></textarea>
                                </div>

                                <div class="form-buttons">
                                    <button type="submit" class="btn btn-primary">确定</button>
                                    <button type="button" class="btn btn-secondary" onclick="document.getElementById('mark-issued-form').style.display='none';">取消</button>
                                </div>
                            </form>
                        </div>
                    </div>

                    <!-- 取消发票表单 -->
                    <div id="mark-cancelled-form" class="form-popup" style="display: none;">
                        <div class="form-container">
                            <h4>取消发票</h4>
                            <form method="post" action="">
                                <input type="hidden" name="action" value="mark_status">
                                <input type="hidden" name="invoice_id" value="<?php echo $invoice['id']; ?>">
                                <input type="hidden" name="status" value="4">

                                <div class="form-group">
                                    <label for="cancel_remark">取消原因：</label>
                                    <textarea id="cancel_remark" name="status_remark" rows="3" required></textarea>
                                </div>

                                <div class="form-buttons">
                                    <button type="submit" class="btn btn-primary" onclick="return confirm('确定要取消此发票吗？此操作不可撤销。')">确定</button>
                                    <button type="button" class="btn btn-secondary" onclick="document.getElementById('mark-cancelled-form').style.display='none';">取消</button>
                                </div>
                            </form>
                        </div>
                    </div>
                <?php endif; ?>

                <!-- 标记为已发送表单 -->
                <?php if ($invoice['status'] == 2): ?>
                    <div id="mark-sent-form" class="form-popup" style="display: none;">
                        <div class="form-container">
                            <h4>标记为已发送</h4>
                            <form method="post" action="">
                                <input type="hidden" name="action" value="mark_status">
                                <input type="hidden" name="invoice_id" value="<?php echo $invoice['id']; ?>">
                                <input type="hidden" name="status" value="3">

                                <div class="form-group">
                                    <label for="sent_remark">发送方式：</label>
                                    <textarea id="sent_remark" name="status_remark" rows="3" required></textarea>
                                    <p class="form-hint">例如：已通过电子邮件发送至客人邮箱</p>
                                </div>

                                <div class="form-buttons">
                                    <button type="submit" class="btn btn-primary">确定</button>
                                    <button type="button" class="btn btn-secondary" onclick="document.getElementById('mark-sent-form').style.display='none';">取消</button>
                                </div>
                            </form>
                        </div>
                    </div>
                <?php endif; ?>

            <?php elseif ($checkin_order): ?>
                <!-- 订单发票列表和申请表单 -->
                <div class="summary-section">
                    <h3>入住信息</h3>
                    <div class="summary-grid">
                        <div class="summary-item">
                            <label>入住单号：</label>
                            <span><?php echo $checkin_order['checkin_no']; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>客人姓名：</label>
                            <span><?php echo $checkin_order['guest_name']; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>房间号：</label>
                            <span><?php echo $checkin_order['room_number']; ?> (<?php echo $checkin_order['type_name']; ?>)</span>
                        </div>
                        <div class="summary-item">
                            <label>入住时间：</label>
                            <span><?php echo date('Y-m-d H:i', strtotime($checkin_order['checkin_time'])); ?></span>
                        </div>
                        <div class="summary-item">
                            <label>退房时间：</label>
                            <span><?php echo $checkin_order['checkout_time'] ? date('Y-m-d H:i', strtotime($checkin_order['checkout_time'])) : '-'; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>消费总额：</label>
                            <span>￥<?php echo number_format($checkin_order['total_amount'], 2); ?></span>
                        </div>
                        <div class="summary-item">
                            <label>退房状态：</label>
                            <span><?php echo $checkin_order['status'] == 2 ? '<span class="status-inactive">已退房</span>' : '<span class="status-active">入住中</span>'; ?></span>
                        </div>
                    </div>
                </div>

                <?php if (!empty($order_invoices)): ?>
                    <h3>发票记录</h3>
                    <div class="data-list">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>发票号码</th>
                                    <th>发票抬头</th>
                                    <th>发票类型</th>
                                    <th>开票内容</th>
                                    <th>金额</th>
                                    <th>状态</th>
                                    <th>申请时间</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($order_invoices as $inv): ?>
                                    <tr>
                                        <td><?php echo $inv['invoice_no']; ?></td>
                                        <td><?php echo $inv['title']; ?></td>
                                        <td><?php echo $inv['invoice_type'] == 1 ? '普通发票' : '专用发票'; ?></td>
                                        <td>
                                            <?php
                                            $content_types = [
                                                1 => '住宿费',
                                                2 => '餐饮费',
                                                3 => '综合服务费'
                                            ];
                                            echo isset($content_types[$inv['content']]) ? $content_types[$inv['content']] : '未知';
                                            ?>
                                        </td>
                                        <td>￥<?php echo number_format($inv['amount'], 2); ?></td>
                                        <td>
                                            <?php
                                            $status_classes = [
                                                1 => 'status-active',
                                                2 => 'status-success',
                                                3 => 'status-success',
                                                4 => 'status-inactive'
                                            ];
                                            $status_texts = [
                                                1 => '已申请',
                                                2 => '已开具',
                                                3 => '已发送',
                                                4 => '已取消'
                                            ];
                                            $status_class = isset($status_classes[$inv['status']]) ? $status_classes[$inv['status']] : '';
                                            $status_text = isset($status_texts[$inv['status']]) ? $status_texts[$inv['status']] : '未知';
                                            echo "<span class=\"{$status_class}\">{$status_text}</span>";
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($inv['issue_time'])); ?></td>
                                        <td>
                                            <a href="invoice.php?invoice_id=<?php echo $inv['id']; ?>&print=true" class="btn btn-primary">打印</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>

                <!-- 订单发票列表和申请表单 -->
                <?php if (!$show_add_form && !$edit_member && !$adjust_points_member): ?>
                    <?php if (empty($order_invoices)): ?>
                        <h3>申请发票</h3>
                        <div class="form-container">
                            <form method="post" action="">
                                <input type="hidden" name="action" value="apply_invoice">
                                <input type="hidden" name="checkin_id" value="<?php echo $checkin_order['id']; ?>">

                                <div class="form-group">
                                    <label for="invoice_title">发票抬头：</label>
                                    <input type="text" id="invoice_title" name="invoice_title" value="<?php echo $checkin_order['guest_name']; ?>" required>
                                </div>

                                <div class="form-group">
                                    <label for="tax_number">纳税人识别号：</label>
                                    <input type="text" id="tax_number" name="tax_number">
                                    <p class="form-hint">如不填写则视为个人或非增值税发票</p>
                                </div>

                                <div class="form-group">
                                    <label for="invoice_type">发票类型：</label>
                                    <select id="invoice_type" name="invoice_type">
                                        <option value="1">增值税普通发票</option>
                                        <option value="2">增值税专用发票</option>
                                    </select>
                                </div>

                                <div class="form-group">
                                    <label for="invoice_content">发票内容：</label>
                                    <select id="invoice_content" name="invoice_content">
                                        <option value="1">住宿费</option>
                                        <option value="2">餐饮费</option>
                                        <option value="3">综合服务费</option>
                                    </select>
                                </div>

                                <div class="form-group">
                                    <label for="amount">发票金额：</label>
                                    <input type="number" id="amount" name="amount" value="<?php echo $checkin_order['total_amount']; ?>" min="0.01" step="0.01" required>
                                    <p class="form-hint">默认为消费总额，可根据需要修改</p>
                                </div>

                                <div class="form-group">
                                    <label for="email">电子邮箱：</label>
                                    <input type="email" id="email" name="email" value="<?php echo $checkin_order['member_id'] ? $checkin_order['member_email'] : ''; ?>">
                                    <p class="form-hint">用于接收电子发票</p>
                                </div>

                                <div class="form-group">
                                    <label for="remark">备注：</label>
                                    <textarea id="remark" name="remark" rows="3"></textarea>
                                </div>

                                <div class="form-buttons">
                                    <button type="submit" class="btn btn-primary">申请发票</button>
                                    <a href="index.php" class="btn btn-secondary">返回</a>
                                </div>
                            </form>
                        </div>
                    <?php endif; ?>
                <?php endif; ?>
            <?php endif; ?>

            <?php if (!$checkin_id && !$invoice_id): ?>
                <h3>发票列表</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>发票号码</th>
                                <th>客人姓名</th>
                                <th>房间号</th>
                                <th>发票抬头</th>
                                <th>金额</th>
                                <th>状态</th>
                                <th>发票日期</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($recent_invoices)): ?>
                                <?php foreach ($recent_invoices as $inv): ?>
                                    <tr>
                                        <td><?php echo $inv['invoice_no']; ?></td>
                                        <td><?php echo $inv['guest_name']; ?></td>
                                        <td><?php echo $inv['room_number']; ?></td>
                                        <td><?php echo $inv['title']; ?></td>
                                        <td>￥<?php echo number_format($inv['amount'], 2); ?></td>
                                        <td>
                                            <?php
                                            $status_texts = [1 => '已申请', 2 => '已开具', 3 => '已发送', 4 => '已取消'];
                                            echo isset($status_texts[$inv['status']]) ? $status_texts[$inv['status']] : '未知';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d', strtotime($inv['issue_time'])); ?></td>
                                        <td>
                                            <a href="invoice.php?invoice_id=<?php echo $inv['id']; ?>" class="btn btn-sm btn-details">详情</a>
                                            <a href="invoice.php?invoice_id=<?php echo $inv['id']; ?>&print=true" class="btn btn-sm btn-primary">打印</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无发票记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>