<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('customer_member');

// 记录访问日志
record_log('访问会员管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加会员
    if ($_POST['action'] == 'add') {
        $member_no = isset($_POST['member_no']) ? trim($_POST['member_no']) : '';
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $gender = isset($_POST['gender']) ? intval($_POST['gender']) : 0;
        $mobile = isset($_POST['mobile']) ? trim($_POST['mobile']) : '';
        $email = isset($_POST['email']) ? trim($_POST['email']) : '';
        $id_type = isset($_POST['id_type']) ? intval($_POST['id_type']) : 1;
        $id_number = isset($_POST['id_number']) ? trim($_POST['id_number']) : '';
        $birthday = isset($_POST['birthday']) && !empty($_POST['birthday']) ? $_POST['birthday'] : null;
        $level_id = isset($_POST['level_id']) ? intval($_POST['level_id']) : 1;
        $points = isset($_POST['points']) ? intval($_POST['points']) : 0;
        $room_type = isset($_POST['room_type']) ? trim($_POST['room_type']) : '';
        $is_smoking = isset($_POST['is_smoking']) ? intval($_POST['is_smoking']) : 0;
        $bed_preference = isset($_POST['bed_preference']) ? trim($_POST['bed_preference']) : '';
        $floor_preference = isset($_POST['floor_preference']) ? trim($_POST['floor_preference']) : '';
        $other_requests = isset($_POST['other_requests']) ? trim($_POST['other_requests']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($member_no) || empty($name) || empty($mobile)) {
            $error = '请填写完整会员信息！';
        } else {
            try {
                // 检查会员编号是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM guest_members WHERE member_no = ?");
                $stmt->execute([$member_no]);
                if ($stmt->fetchColumn() > 0) {
                    $error = '会员编号已存在！';
                } else {
                    // 检查手机号是否已存在
                    $stmt = $pdo->prepare("SELECT COUNT(*) FROM guest_members WHERE mobile = ?");
                    $stmt->execute([$mobile]);
                    if ($stmt->fetchColumn() > 0) {
                        $error = '手机号已被注册！';
                    } else {
                        $stmt = $pdo->prepare("
                            INSERT INTO guest_members (
                                member_no, name, gender, mobile, email, id_type, id_number, 
                                birthday, level_id, points, room_type, is_smoking, 
                                bed_preference, floor_preference, other_requests, status
                            ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                        ");
                        $result = $stmt->execute([
                            $member_no,
                            $name,
                            $gender,
                            $mobile,
                            $email,
                            $id_type,
                            $id_number,
                            $birthday,
                            $level_id,
                            $points,
                            $room_type,
                            $is_smoking,
                            $bed_preference,
                            $floor_preference,
                            $other_requests,
                            $status
                        ]);

                        if ($result) {
                            record_log("添加会员：{$name}，会员编号：{$member_no}");
                            $success = '会员添加成功！';
                        } else {
                            $error = '会员添加失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑会员
    elseif ($_POST['action'] == 'edit') {
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;
        $member_no = isset($_POST['member_no']) ? trim($_POST['member_no']) : '';
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $gender = isset($_POST['gender']) ? intval($_POST['gender']) : 0;
        $mobile = isset($_POST['mobile']) ? trim($_POST['mobile']) : '';
        $email = isset($_POST['email']) ? trim($_POST['email']) : '';
        $id_type = isset($_POST['id_type']) ? intval($_POST['id_type']) : 1;
        $id_number = isset($_POST['id_number']) ? trim($_POST['id_number']) : '';
        $birthday = isset($_POST['birthday']) && !empty($_POST['birthday']) ? $_POST['birthday'] : null;
        $level_id = isset($_POST['level_id']) ? intval($_POST['level_id']) : 1;
        $points = isset($_POST['points']) ? intval($_POST['points']) : 0;
        $room_type = isset($_POST['room_type']) ? trim($_POST['room_type']) : '';
        $is_smoking = isset($_POST['is_smoking']) ? intval($_POST['is_smoking']) : 0;
        $bed_preference = isset($_POST['bed_preference']) ? trim($_POST['bed_preference']) : '';
        $floor_preference = isset($_POST['floor_preference']) ? trim($_POST['floor_preference']) : '';
        $other_requests = isset($_POST['other_requests']) ? trim($_POST['other_requests']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($member_id <= 0 || empty($member_no) || empty($name) || empty($mobile)) {
            $error = '请填写完整会员信息！';
        } else {
            try {
                // 检查会员编号是否已存在（排除当前会员）
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM guest_members WHERE member_no = ? AND id != ?");
                $stmt->execute([$member_no, $member_id]);
                if ($stmt->fetchColumn() > 0) {
                    $error = '会员编号已存在！';
                } else {
                    // 检查手机号是否已存在（排除当前会员）
                    $stmt = $pdo->prepare("SELECT COUNT(*) FROM guest_members WHERE mobile = ? AND id != ?");
                    $stmt->execute([$mobile, $member_id]);
                    if ($stmt->fetchColumn() > 0) {
                        $error = '手机号已被注册！';
                    } else {
                        $stmt = $pdo->prepare("
                            UPDATE guest_members 
                            SET member_no = ?, name = ?, gender = ?, mobile = ?, email = ?, 
                                id_type = ?, id_number = ?, birthday = ?, level_id = ?, points = ?, 
                                room_type = ?, is_smoking = ?, bed_preference = ?, floor_preference = ?, 
                                other_requests = ?, status = ? 
                            WHERE id = ?
                        ");
                        $result = $stmt->execute([
                            $member_no,
                            $name,
                            $gender,
                            $mobile,
                            $email,
                            $id_type,
                            $id_number,
                            $birthday,
                            $level_id,
                            $points,
                            $room_type,
                            $is_smoking,
                            $bed_preference,
                            $floor_preference,
                            $other_requests,
                            $status,
                            $member_id
                        ]);

                        if ($result) {
                            record_log("编辑会员：{$name}，会员编号：{$member_no}");
                            $success = '会员信息更新成功！';
                        } else {
                            $error = '会员信息更新失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除会员
    elseif ($_POST['action'] == 'delete') {
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;

        if ($member_id <= 0) {
            $error = '无效的会员ID！';
        } else {
            try {
                // 获取会员信息，用于日志记录
                $stmt = $pdo->prepare("SELECT name, member_no FROM guest_members WHERE id = ?");
                $stmt->execute([$member_id]);
                $member = $stmt->fetch();

                if (!$member) {
                    $error = '会员不存在！';
                } else {
                    $stmt = $pdo->prepare("DELETE FROM guest_members WHERE id = ?");
                    $result = $stmt->execute([$member_id]);

                    if ($result) {
                        record_log("删除会员：{$member['name']}，会员编号：{$member['member_no']}");
                        $success = '会员删除成功！';
                    } else {
                        $error = '会员删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 调整会员积分
    elseif ($_POST['action'] == 'adjust_points') {
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;
        $points_change = isset($_POST['points_change']) ? intval($_POST['points_change']) : 0;
        $points_reason = isset($_POST['points_reason']) ? intval($_POST['points_reason']) : 4;
        $points_remark = isset($_POST['points_remark']) ? trim($_POST['points_remark']) : '';

        if ($member_id <= 0) {
            $error = '无效的会员ID！';
        } elseif ($points_change == 0) {
            $error = '积分变动不能为0！';
        } else {
            try {
                // 获取会员当前积分
                $stmt = $pdo->prepare("SELECT name, member_no, points FROM guest_members WHERE id = ?");
                $stmt->execute([$member_id]);
                $member = $stmt->fetch();

                if (!$member) {
                    $error = '会员不存在！';
                } else {
                    $new_points = $member['points'] + $points_change;
                    if ($new_points < 0) {
                        $error = '积分不足，无法扣减！';
                    } else {
                        $stmt = $pdo->prepare("UPDATE guest_members SET points = ? WHERE id = ?");
                        $result = $stmt->execute([$new_points, $member_id]);

                        if ($result) {
                            $change_text = $points_change > 0 ? "增加" : "减少";
                            $points_abs = abs($points_change);

                            $reasons = ['入住获取', '消费获取', '积分兑换', '积分调整', '积分过期'];
                            $reason_text = isset($reasons[$points_reason - 1]) ? $reasons[$points_reason - 1] : '未知原因';

                            $log_message = "调整会员{$member['name']}({$member['member_no']})积分：{$change_text}{$points_abs}，原因：{$reason_text}";
                            if (!empty($points_remark)) {
                                $log_message .= "，备注：{$points_remark}";
                            }

                            record_log($log_message);
                            $success = "会员积分{$change_text}成功！";
                        } else {
                            $error = '积分调整失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 如果是编辑请求，获取会员详情
$edit_member = null;
if (isset($_GET['edit']) && intval($_GET['edit']) > 0) {
    $member_id = intval($_GET['edit']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM guest_members WHERE id = ?");
        $stmt->execute([$member_id]);
        $edit_member = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取会员详情失败：' . $e->getMessage();
    }
}

// 判断是否查看详情
$view_member_id = isset($_GET['view']) ? intval($_GET['view']) : 0;

// 判断是否显示调整积分表单
$adjust_points_member = null;
if (isset($_GET['adjust_points']) && intval($_GET['adjust_points']) > 0) {
    $member_id = intval($_GET['adjust_points']);
    try {
        $stmt = $pdo->prepare("SELECT id, name, member_no, points FROM guest_members WHERE id = ?");
        $stmt->execute([$member_id]);
        $adjust_points_member = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取会员信息失败：' . $e->getMessage();
    }
}

// 获取所有会员等级
try {
    $stmt = $pdo->query("SELECT id, level_name FROM guest_member_levels ORDER BY id");
    $levels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员等级列表失败：' . $e->getMessage();
    $levels = [];
}

// 获取所有会员
try {
    $stmt = $pdo->query("
        SELECT m.*, l.level_name 
        FROM guest_members m 
        LEFT JOIN guest_member_levels l ON m.level_id = l.id 
        ORDER BY m.id DESC
    ");
    $members = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员列表失败：' . $e->getMessage();
    $members = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客户管理</a> &gt; 会员管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$edit_member && !$adjust_points_member): ?>
                    <a href="member.php?show_form=add" class="btn btn-primary">添加会员</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加会员表单 -->
                <h3>添加会员</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="member_no">会员编号：</label>
                            <input type="text" id="member_no" name="member_no" required>
                        </div>

                        <div class="form-group">
                            <label for="name">姓名：</label>
                            <input type="text" id="name" name="name" required>
                        </div>

                        <div class="form-group">
                            <label for="gender">性别：</label>
                            <select id="gender" name="gender">
                                <option value="0">未知</option>
                                <option value="1">男</option>
                                <option value="2">女</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="mobile">手机号：</label>
                            <input type="text" id="mobile" name="mobile" required>
                        </div>

                        <div class="form-group">
                            <label for="email">邮箱：</label>
                            <input type="email" id="email" name="email">
                        </div>

                        <div class="form-group">
                            <label for="id_type">证件类型：</label>
                            <select id="id_type" name="id_type">
                                <option value="1">身份证</option>
                                <option value="2">护照</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="id_number">证件号码：</label>
                            <input type="text" id="id_number" name="id_number">
                        </div>

                        <div class="form-group">
                            <label for="birthday">生日：</label>
                            <input type="date" id="birthday" name="birthday">
                        </div>

                        <div class="form-group">
                            <label for="level_id">会员等级：</label>
                            <select id="level_id" name="level_id" required>
                                <?php foreach ($levels as $level): ?>
                                    <option value="<?php echo $level['id']; ?>"><?php echo $level['level_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="points">积分：</label>
                            <input type="number" id="points" name="points" value="0" min="0">
                        </div>

                        <h4>客户偏好</h4>

                        <div class="form-group">
                            <label for="room_type">偏好房型：</label>
                            <input type="text" id="room_type" name="room_type">
                        </div>

                        <div class="form-group">
                            <label for="is_smoking">是否吸烟：</label>
                            <select id="is_smoking" name="is_smoking">
                                <option value="0">否</option>
                                <option value="1">是</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="bed_preference">床型偏好：</label>
                            <input type="text" id="bed_preference" name="bed_preference">
                        </div>

                        <div class="form-group">
                            <label for="floor_preference">楼层偏好：</label>
                            <input type="text" id="floor_preference" name="floor_preference">
                        </div>

                        <div class="form-group">
                            <label for="other_requests">其他特殊需求：</label>
                            <textarea id="other_requests" name="other_requests" rows="3"></textarea>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1">启用</option>
                                <option value="0">禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="member.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($edit_member): ?>
                <!-- 编辑会员表单 -->
                <h3>编辑会员</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="edit">
                        <input type="hidden" name="member_id" value="<?php echo $edit_member['id']; ?>">

                        <div class="form-group">
                            <label for="member_no">会员编号：</label>
                            <input type="text" id="member_no" name="member_no" value="<?php echo $edit_member['member_no']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="name">姓名：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_member['name']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="gender">性别：</label>
                            <select id="gender" name="gender">
                                <option value="0" <?php echo $edit_member['gender'] == 0 ? 'selected' : ''; ?>>未知</option>
                                <option value="1" <?php echo $edit_member['gender'] == 1 ? 'selected' : ''; ?>>男</option>
                                <option value="2" <?php echo $edit_member['gender'] == 2 ? 'selected' : ''; ?>>女</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="mobile">手机号：</label>
                            <input type="text" id="mobile" name="mobile" value="<?php echo $edit_member['mobile']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="email">邮箱：</label>
                            <input type="email" id="email" name="email" value="<?php echo $edit_member['email']; ?>">
                        </div>

                        <div class="form-group">
                            <label for="id_type">证件类型：</label>
                            <select id="id_type" name="id_type">
                                <option value="1" <?php echo $edit_member['id_type'] == 1 ? 'selected' : ''; ?>>身份证</option>
                                <option value="2" <?php echo $edit_member['id_type'] == 2 ? 'selected' : ''; ?>>护照</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="id_number">证件号码：</label>
                            <input type="text" id="id_number" name="id_number" value="<?php echo $edit_member['id_number']; ?>">
                        </div>

                        <div class="form-group">
                            <label for="birthday">生日：</label>
                            <input type="date" id="birthday" name="birthday" value="<?php echo $edit_member['birthday']; ?>">
                        </div>

                        <div class="form-group">
                            <label for="level_id">会员等级：</label>
                            <select id="level_id" name="level_id" required>
                                <?php foreach ($levels as $level): ?>
                                    <option value="<?php echo $level['id']; ?>" <?php echo $edit_member['level_id'] == $level['id'] ? 'selected' : ''; ?>><?php echo $level['level_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="points">积分：</label>
                            <input type="number" id="points" name="points" min="0" value="<?php echo $edit_member['points']; ?>">
                        </div>

                        <h4>客户偏好</h4>

                        <div class="form-group">
                            <label for="room_type">偏好房型：</label>
                            <input type="text" id="room_type" name="room_type" value="<?php echo $edit_member['room_type']; ?>">
                        </div>

                        <div class="form-group">
                            <label for="is_smoking">是否吸烟：</label>
                            <select id="is_smoking" name="is_smoking">
                                <option value="0" <?php echo $edit_member['is_smoking'] == 0 ? 'selected' : ''; ?>>否</option>
                                <option value="1" <?php echo $edit_member['is_smoking'] == 1 ? 'selected' : ''; ?>>是</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="bed_preference">床型偏好：</label>
                            <input type="text" id="bed_preference" name="bed_preference" value="<?php echo $edit_member['bed_preference']; ?>">
                        </div>

                        <div class="form-group">
                            <label for="floor_preference">楼层偏好：</label>
                            <input type="text" id="floor_preference" name="floor_preference" value="<?php echo $edit_member['floor_preference']; ?>">
                        </div>

                        <div class="form-group">
                            <label for="other_requests">其他特殊需求：</label>
                            <textarea id="other_requests" name="other_requests" rows="3"><?php echo $edit_member['other_requests']; ?></textarea>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo $edit_member['status'] == 1 ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo $edit_member['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="member.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($adjust_points_member): ?>
                <!-- 调整积分表单 -->
                <h3>调整会员积分 - <?php echo $adjust_points_member['name']; ?> (<?php echo $adjust_points_member['member_no']; ?>)</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="adjust_points">
                        <input type="hidden" name="member_id" value="<?php echo $adjust_points_member['id']; ?>">

                        <div class="form-group">
                            <label>当前积分：</label>
                            <span class="form-static"><?php echo $adjust_points_member['points']; ?></span>
                        </div>

                        <div class="form-group">
                            <label for="points_change">积分变动：</label>
                            <input type="number" id="points_change" name="points_change" required>
                            <p class="form-hint">正数为增加积分，负数为减少积分</p>
                        </div>

                        <div class="form-group">
                            <label for="points_reason">变动原因：</label>
                            <select id="points_reason" name="points_reason">
                                <option value="1">入住获取</option>
                                <option value="2">消费获取</option>
                                <option value="3">积分兑换</option>
                                <option value="4">积分调整</option>
                                <option value="5">积分过期</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="points_remark">备注：</label>
                            <textarea id="points_remark" name="points_remark" rows="3"></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="member.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <?php if (!$show_add_form && !$edit_member && !$adjust_points_member): ?>
                <h3>会员列表</h3>
                <!-- 会员列表 -->
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>会员编号</th>
                                <th>姓名</th>
                                <th>性别</th>
                                <th>手机号</th>
                                <th>会员等级</th>
                                <th>积分</th>
                                <th>入住次数</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($members as $member): ?>
                                <tr>
                                    <td><?php echo $member['id']; ?></td>
                                    <td><?php echo $member['member_no']; ?></td>
                                    <td><?php echo $member['name']; ?></td>
                                    <td>
                                        <?php
                                        if ($member['gender'] == 1) {
                                            echo '男';
                                        } elseif ($member['gender'] == 2) {
                                            echo '女';
                                        } else {
                                            echo '未知';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $member['mobile']; ?></td>
                                    <td><?php echo $member['level_name']; ?></td>
                                    <td><?php echo $member['points']; ?></td>
                                    <td><?php echo $member['stay_count']; ?></td>
                                    <td>
                                        <?php if ($member['status'] == 1): ?>
                                            <span class="status-active">启用</span>
                                        <?php else: ?>
                                            <span class="status-inactive">禁用</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <a href="member.php?view=<?php echo $member['id']; ?>" class="btn btn-sm btn-details">详情</a>
                                        <a href="member.php?edit=<?php echo $member['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                        <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此会员吗？此操作不可恢复！');">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="member_id" value="<?php echo $member['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                        </form>

                                        <a href="member.php?adjust_points=<?php echo $member['id']; ?>" class="btn btn-sm btn-warning">积分</a>
                                    </td>
                                </tr>
                                <?php if ($view_member_id == $member['id']): ?>
                                    <tr id="member-<?php echo $member['id']; ?>">
                                        <td colspan="10" class="details-row">
                                            <div class="member-details">
                                                <div class="detail-group">
                                                    <h4>基本信息</h4>
                                                    <p><strong>邮箱：</strong> <?php echo $member['email'] ?: '-'; ?></p>
                                                    <p><strong>证件：</strong> <?php echo $member['id_type'] == 1 ? '身份证' : '护照'; ?>: <?php echo $member['id_number'] ?: '-'; ?></p>
                                                    <p><strong>生日：</strong> <?php echo $member['birthday'] ?: '-'; ?></p>
                                                    <p><strong>注册时间：</strong> <?php echo date('Y-m-d H:i', strtotime($member['create_time'])); ?></p>
                                                </div>

                                                <div class="detail-group">
                                                    <h4>消费信息</h4>
                                                    <p><strong>累计消费：</strong> ￥<?php echo number_format($member['total_amount'], 2); ?></p>
                                                    <p><strong>入住次数：</strong> <?php echo $member['stay_count']; ?></p>
                                                </div>

                                                <div class="detail-group">
                                                    <h4>客户偏好</h4>
                                                    <p><strong>偏好房型：</strong> <?php echo $member['room_type'] ?: '-'; ?></p>
                                                    <p><strong>是否吸烟：</strong> <?php echo $member['is_smoking'] ? '是' : '否'; ?></p>
                                                    <p><strong>床型偏好：</strong> <?php echo $member['bed_preference'] ?: '-'; ?></p>
                                                    <p><strong>楼层偏好：</strong> <?php echo $member['floor_preference'] ?: '-'; ?></p>
                                                    <p><strong>其他需求：</strong> <?php echo $member['other_requests'] ?: '-'; ?></p>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endif; ?>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>